Struct RoomMessageEventContentWithoutRelation
#[non_exhaustive]pub struct RoomMessageEventContentWithoutRelation {
pub msgtype: MessageType,
pub mentions: Option<Mentions>,
}Expand description
Form of RoomMessageEventContent without relation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.msgtype: MessageTypeA key which identifies the type of message being sent.
This also holds the specific content of each message.
mentions: Option<Mentions>The mentions of this event.
Implementations
impl RoomMessageEventContentWithoutRelation
impl RoomMessageEventContentWithoutRelation
pub fn new(msgtype: MessageType) -> RoomMessageEventContentWithoutRelation
pub fn new(msgtype: MessageType) -> RoomMessageEventContentWithoutRelation
Creates a new RoomMessageEventContentWithoutRelation with the given MessageType.
pub fn text_plain(
body: impl Into<String>,
) -> RoomMessageEventContentWithoutRelation
pub fn text_plain( body: impl Into<String>, ) -> RoomMessageEventContentWithoutRelation
A constructor to create a plain text message.
pub fn text_html(
body: impl Into<String>,
html_body: impl Into<String>,
) -> RoomMessageEventContentWithoutRelation
pub fn text_html( body: impl Into<String>, html_body: impl Into<String>, ) -> RoomMessageEventContentWithoutRelation
A constructor to create an html message.
pub fn text_markdown(
body: impl AsRef<str> + Into<String>,
) -> RoomMessageEventContentWithoutRelation
Available on crate feature markdown only.
pub fn text_markdown( body: impl AsRef<str> + Into<String>, ) -> RoomMessageEventContentWithoutRelation
markdown only.A constructor to create a markdown message.
pub fn notice_plain(
body: impl Into<String>,
) -> RoomMessageEventContentWithoutRelation
pub fn notice_plain( body: impl Into<String>, ) -> RoomMessageEventContentWithoutRelation
A constructor to create a plain text notice.
pub fn notice_html(
body: impl Into<String>,
html_body: impl Into<String>,
) -> RoomMessageEventContentWithoutRelation
pub fn notice_html( body: impl Into<String>, html_body: impl Into<String>, ) -> RoomMessageEventContentWithoutRelation
A constructor to create an html notice.
pub fn notice_markdown(
body: impl AsRef<str> + Into<String>,
) -> RoomMessageEventContentWithoutRelation
Available on crate feature markdown only.
pub fn notice_markdown( body: impl AsRef<str> + Into<String>, ) -> RoomMessageEventContentWithoutRelation
markdown only.A constructor to create a markdown notice.
pub fn emote_plain(
body: impl Into<String>,
) -> RoomMessageEventContentWithoutRelation
pub fn emote_plain( body: impl Into<String>, ) -> RoomMessageEventContentWithoutRelation
A constructor to create a plain text emote.
pub fn emote_html(
body: impl Into<String>,
html_body: impl Into<String>,
) -> RoomMessageEventContentWithoutRelation
pub fn emote_html( body: impl Into<String>, html_body: impl Into<String>, ) -> RoomMessageEventContentWithoutRelation
A constructor to create an html emote.
pub fn emote_markdown(
body: impl AsRef<str> + Into<String>,
) -> RoomMessageEventContentWithoutRelation
Available on crate feature markdown only.
pub fn emote_markdown( body: impl AsRef<str> + Into<String>, ) -> RoomMessageEventContentWithoutRelation
markdown only.A constructor to create a markdown emote.
pub fn with_relation(
self,
relates_to: Option<Relation<RoomMessageEventContentWithoutRelation>>,
) -> RoomMessageEventContent
pub fn with_relation( self, relates_to: Option<Relation<RoomMessageEventContentWithoutRelation>>, ) -> RoomMessageEventContent
Transform self into a RoomMessageEventContent with the given relation.
pub fn make_reply_to<'a>(
self,
metadata: impl Into<ReplyMetadata<'a>>,
forward_thread: ForwardThread,
add_mentions: AddMentions,
) -> RoomMessageEventContent
pub fn make_reply_to<'a>( self, metadata: impl Into<ReplyMetadata<'a>>, forward_thread: ForwardThread, add_mentions: AddMentions, ) -> RoomMessageEventContent
Turns self into a rich reply to the message using the given metadata.
Sets the in_reply_to field inside relates_to, and optionally the rel_type to
m.thread if the metadata has a thread and ForwardThread::Yes is used.
If AddMentions::Yes is used, the sender in the metadata is added as a user mention.
pub fn make_for_thread<'a>(
self,
metadata: impl Into<ReplyMetadata<'a>>,
is_reply: ReplyWithinThread,
add_mentions: AddMentions,
) -> RoomMessageEventContent
pub fn make_for_thread<'a>( self, metadata: impl Into<ReplyMetadata<'a>>, is_reply: ReplyWithinThread, add_mentions: AddMentions, ) -> RoomMessageEventContent
Turns self into a new message for a thread, that is optionally a reply.
Looks for the thread in the given metadata. If it exists, this message will be in the same
thread. If it doesn’t, a new thread is created with the event_id in the metadata as the
root.
It also sets the in_reply_to field inside relates_to to point the event_id
in the metadata. If ReplyWithinThread::Yes is used, the metadata should be constructed
from the event to make a reply to, otherwise it should be constructed from the latest
event in the thread.
If AddMentions::Yes is used, the sender in the metadata is added as a user mention.
pub fn make_replacement(
self,
metadata: impl Into<ReplacementMetadata>,
) -> RoomMessageEventContent
pub fn make_replacement( self, metadata: impl Into<ReplacementMetadata>, ) -> RoomMessageEventContent
Turns self into a replacement (or edit) for a given message.
The first argument after self can be &OriginalRoomMessageEvent or
&OriginalSyncRoomMessageEvent if you don’t want to create ReplacementMetadata separately
before calling this function.
This takes the content and sets it in m.new_content, and modifies the content to include
a fallback.
If this message contains Mentions, they are copied into m.new_content to keep the same
mentions, but the ones in content are filtered with the ones in the
ReplacementMetadata so only new mentions will trigger a notification.
Panics
Panics if self has a formatted_body with a format other than HTML.
pub fn add_mentions(
self,
mentions: Mentions,
) -> RoomMessageEventContentWithoutRelation
pub fn add_mentions( self, mentions: Mentions, ) -> RoomMessageEventContentWithoutRelation